summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog42
-rwxr-xr-xdoc/Makefile16
-rw-r--r--doc/gnu.xpm138
-rw-r--r--doc/groff.texinfo4
-rwxr-xr-xdoc/homepage.ms69
-rw-r--r--src/devices/grops/psrm.cc4
-rw-r--r--src/include/lib.h6
-rw-r--r--src/libs/libdriver/input.cc10
-rw-r--r--src/libs/libgroff/Makefile.sub4
-rw-r--r--src/libs/libgroff/font.cc15
-rwxr-xr-xsrc/preproc/eqn/eqn.cc1277
-rw-r--r--src/preproc/eqn/lex.cc8
-rw-r--r--src/preproc/eqn/main.cc8
-rw-r--r--src/preproc/grn/grn.man4
-rw-r--r--src/preproc/grn/main.cc2
-rw-r--r--src/preproc/pic/lex.cc14
-rw-r--r--src/preproc/pic/main.cc10
-rw-r--r--src/preproc/pic/pic.man2
-rw-r--r--src/preproc/refer/command.cc7
-rw-r--r--src/preproc/refer/refer.cc22
-rw-r--r--src/preproc/tbl/main.cc6
-rw-r--r--src/roff/troff/env.cc4
-rw-r--r--src/roff/troff/input.cc36
-rw-r--r--src/roff/troff/troff.man4
-rw-r--r--tmac/e.tmac4
-rw-r--r--win32-diffs2
26 files changed, 313 insertions, 1405 deletions
diff --git a/ChangeLog b/ChangeLog
index 1a2eed11..626660e9 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,45 @@
+2002-02-10 Werner LEMBERG <wl@gnu.org>
+
+ Illegal -> Invalid.
+
+ * src/libs/libgroff/illegal.cc: Renamed to ...
+ * src/libs/libgroff/invalid.cc: This.
+ (illegal_char_table): Renamed to ...
+ (invalid_char_table): This.
+ * src/libs/libgroff/Makefile.sub: Updated.
+ * win32-diffs: Updated.
+
+ * doc/groff.texinfo, src/devices/grops/psrm.cc (ps_get_line),
+ src/libs/libdriver/input.cc (fatal_command, parse_color_command,
+ parse_x_command), src/libs/libgroff/font.cc (text_file::next,
+ font::load), src/preproc/eqn/main.cc (read_line, main),
+ src/preproc/eqn/lex.cc (file_input::read_line),
+ src/preproc/pic/lex.cc (file_input::read_line,
+ simple_file_input::get, simple_file_input::peek),
+ src/preproc/pic/main.cc (top_input::get, top_input::peek),
+ src/preproc/pic/pic.man, src/preproc/refer/main.cc
+ (input_stack::push_file), src/preproc/refer/refer.cc (do_file,
+ do_bib), src/preproc/tbl/main.cc (table_input::get),
+ src/preproc/grn/grn.man, src/preproc/grn/main.cc (interpret),
+ src/roff/troff/input.cc (file_iterator::fill, file_iterator::peek,
+ do_zero_width, read_request, encode_char, ps_get_line,
+ transparent_file, get_char_for_escape_name, transparent_translate,
+ asciify, input_char_description, read_string, set_string),
+ src/roff/troff/env.cc (environment::add_html_tag),
+ src/roff/troff/troff.man, tmac/e.tmac (`@(', `(f'): Do it.
+
+ * src/include/lib.h: Updated.
+
+ * src/preproc/eqn/eqn.cc: Removed.
+
+2002-02-09 Werner LEMBERG <wl@gnu.org>
+
+ * doc/gnu.xpm: New image.
+ * doc/Makefile (DOCS): Add homepage.ps
+ Add rules for converting xpm->png and xpm->eps.
+ Use `gnu.{xpm,eps}' as image names.
+ * doc/homepage.ms: Updated.
+
2002-02-09 Gaius Mulley <gaius@glam.ac.uk>
* tmac/www.tmac (www-error): New macro, replacing calls to `@error'.
diff --git a/doc/Makefile b/doc/Makefile
index 874fa663..5d7cffcf 100755
--- a/doc/Makefile
+++ b/doc/Makefile
@@ -22,7 +22,7 @@ FFLAG=-F../font
TROFF=../src/roff/troff/troff -M../tmac $(FFLAG)
GROFF=../src/roff/groff/groff -p -e -t
GROPS=../src/devices/grops/grops $(FFLAG)
-DOCS=meref.ps meintro.ps pic.ps pic.html homepage.html
+DOCS=meref.ps meintro.ps pic.ps pic.html homepage.ps homepage.html
MEMACROS=../tmac/tmac.e
SOELIM=../src/preproc/soelim/soelim
@@ -59,7 +59,6 @@ all: $(DOCS)
$(SOELIM) $< \
| sed -e "s;@VERSION@;$(version)$(revision);" \
| $(TROFF) -Tps $(FFLAG) -me >$@
-
.tr.dit:
$(TROFF) -Tps $< >$@
@@ -71,7 +70,6 @@ all: $(DOCS)
sed -e "s;@VERSION@;$(version)$(revision);" $< \
| $(GROFF) -P-b -P-I`echo $< | sed -e 's|.ms$$||'` \
-P-D -Pimg -Thtml $(FFLAG) -U -ms >$@
-
.ms.ascii:
GROFF_TMAC_PATH=../tmac; \
export GROFF_TMAC_PATH; \
@@ -79,7 +77,6 @@ all: $(DOCS)
export GROFF_BIN_PATH; \
sed -e "s;@VERSION@;$(version)$(revision);" $< \
| $(GROFF) -Tascii $(FFLAG) -U -ms -mwww >$@
-
.ms.ps:
GROFF_TMAC_PATH=../tmac; \
export GROFF_TMAC_PATH; \
@@ -90,20 +87,21 @@ all: $(DOCS)
.texinfo.dvi:
texi2dvi -e $<
-
.texinfo.pdf:
texi2dvi -e --pdf $<
-
.texinfo.html:
makeinfo --html --no-split $<
groff: groff.texinfo
makeinfo groff.texinfo
-gnubw.eps: gnupng
- pngtopnm gnupng | pnmtops -noturn > gnubw.eps
+gnu.eps: gnu.xpm
+ xpmtoppm gnu.xpm | pnmtops -noturn > gnu.eps
+gnu.png: gnu.xpm
+ xpmtoppm gnu.xpm | pnmtopng > gnu.png
-homepage.html: gnubw.eps
+homepage.html: gnu.png
+homepage.ps: gnu.eps
install:
diff --git a/doc/gnu.xpm b/doc/gnu.xpm
new file mode 100644
index 00000000..6b764305
--- /dev/null
+++ b/doc/gnu.xpm
@@ -0,0 +1,138 @@
+/* XPM */
+static char *noname[] = {
+/* width height ncolors chars_per_pixel */
+"129 122 9 1",
+/* colors */
+" c #000",
+". c #FFF",
+"X c #AAA",
+"o c #666",
+"O c #222",
+"+ c #CCC",
+"@ c #888",
+"# c #444",
+"$ c None",
+/* pixels */
+".................................................................................................................................",
+".................................................................................................................................",
+"..................................+..............................................................................................",
+"...........................+@o@o#######oX+...............................................................+X@@@@X+................",
+"........................X##@+..++.......X@oo..........................................................+o #@@XXXoOOX..............",
+"......................@oXX+..+XXX@o@@@+X@+.+@@+.....................................................Xo#@+.X.X....Xo#+............",
+"....................+oX...@@@###O#ooX@O# ##..+o@..................................................X#o.+@o#ooo@oo@++XO@...........",
+"..................XoX++@o@X##ooO#o#o@oOOOO #o+.+oo+...++...............................+X......Xo##@#OOO##oo@@#o#oXX.X#@.........",
+"................oO+..+#O##o##O@##oooooO#@# #oOOX+.##ooX#...............................X.@#o###XO O#O####X@@o@X#@@#@X+X#@........",
+"...............@o..++#@O#@o#O#XXX#@o@o@@+@o@o# oo+++..Xo...............................XX.++XX@o O#@oX+XoX@oo#o# #o@#oX#X.......",
+"..............X@...#XX##O#oX#X+X++X@@#@X++X+@@oXo+X+.@o.................................@+.XX##oo@@+XXX+XXX+X@X #o#O@+++O.......",
+".............X@..+XXX@@o oX@o..Xo#OO OO@@.X.@X+++X#o+...................................XoX+@#X@X+X+X+X@XXXXoo OO#Xo Xo@......",
+"............+@+..+XX@++oo oX++X##@XX....+X@@Xo@@oo@........................................@oo#@ooooo#o@X@@X@XO#O#@o #oooXO......",
+"............#+..X+O#@Xo.+OoXX##+.......................................................................@#O@o@#+X@@O OO #o.oo.....",
+"..........+o...+@oX@XX++++Xoo+............................................................................@@Xo@Xo## OO##@.#.....",
+"..........o...+XXXOX++@+.+O+...............................................................................+o@@OXX#O@o#OoX.X@....",
+".........X@..++oXXXX++X@X#..................................................................................Xo#@+XX#OO##@o+.O....",
+".........O..+.@XX#XX+++X#....................................................................................@#@X++o o@o#X+.#X...",
+"........oX..@@X+o+#oX++#.............................@#O#O##@.................................................Oo+X#X@ ####@.oo...",
+".......+O..+++@@XXXoX+@..........................+o@@+....+Xo##@...........+XX+X+.............................Xo.#@X ##X++#...",
+".......Xo...+X+X@X@+ooX.........................@O+.........+..o#........+o #o## o+...........................@+Ooo+#@@o@@+.O...",
+".......o.....+X+XXoX@o.......................+@oX..X.+@++ooXO@o++o@....+oOo#@oX@@..oOo+........................XooX+XO##OO@X.#...",
+".......o...++X@X+XXo@X......................Xo+...XXX@#@ #O#Oo@..#.@ooo #@##@# OXX@X#o........................#++Xo@# #X+#...",
+"......Xo..X@@@@oXo#+o......................+#+...@O#@o#O@ OO OOoX+. # O O O## O ###O@@#+......................o+XXo##ooXXo.#...",
+"......@X..++.@#@@X#.#......................o...+Xoo #O @ O O ##o@+##O O## O#O+@OX.....................@.o#+@X@o#O#.o...",
+"......#+.+.+XXooOO@@@.....................#+.Xo@ooOO #OO O #Ooo o# # XX.#@....................XXo@X+o@+X@oXo+..",
+"......#......+X@ooO#X....................oX.X@@O##OO o# O OOO O##OOoO O ##+Xo@...................X@+++oo@@XXX+@+..",
+"......o..+XXXX@o@oo#X...................o@.+@o@ O O O O O+O# OO O O Oo.oX..................X+XX#O #X@+XX..",
+"......o...+.+oOO##+#+..................@@.+# O #@o+ ##@ O #@.@X.................@+XXX@O##O##.@+..",
+".....+o..X+++X#ooX+#+.................Xo.+@o O O O@+@oO@+#o @.@.................o..++ooXXX+XX@...",
+".....X@+X@o#o@ooOo.#+................+o.X@## # O O O O o# o XX#@####+# OX+o................#.X@o####o@+@@...",
+".....+@.+.+X@o@+@X.#+................#+@X#oO ## # O O @OXXoo#X.o.o O O OO@.+@..............Xo+X#OO oXo@++@...",
+"......o..++Xooo#oX.@X...............@+XoO O#O # # #@oO@o+o@oXOOXoo O O#O O O @X@@.............@+o ##O#@X.@...",
+"......@.++@O#X@oOX.+@..............XXX@O Oo# O O O+...O@X+XXo+XO##O O#O O O##+@+............o.o#OOXo@@@@X.@...",
+"......o.+XX+@+@#@o..o.............+@+.#o O O #@o+.+Xo###@X.....o@@++X.XX+##@@+Xo O Oo ##.#+..........#+.@O##@#Ooo.+.@...",
+"......o.+.+@X@@+@@o.@+...........@X@##O OO O#oo++..........+........#@#@@Xo#O#X+...+XX++XooO O##X@+........@XXOO##@oo@O@@+oX...",
+"......#...++@o@oooX@+@..........o@X@#OoO#O#+..............+..........+o##o O#.......o+.....+o#@@@O@oX......@XX#O OO#o#@@X@.#+...",
+"......#+.+X+oXOO oXo.X+.......X#X#@O O# Oo+..............X+.............@o+ oX+.......@.......@O#@oOo@ oXX@#X+O@ O@ XXoX.XX@....",
+"......oX++.X####o#Oo@.#@.....o+o#Oo # OX..............+oo X.......X@.X....o#@@@.......@@.......+#@@OooX+@oX#Oo#o#oO#+O@#+X+X+....",
+"......@@.+Xo#ooX# o#XXO@XX@X++# O o+............+O#@O O+.......XXXX....++@O@...+@@+.oX.......X#@##O##XO# O#@ ##OoooXX+@o.....",
+"......+#+.Xo@@XO @##o#O@XX.+o## #.............+##.# #..........X@......@ @...o #+..#........X @o#o#@ # OoOoO#O +XXX+@X.....",
+".......#+.++.@@ o#o X#Oo..X@ #..............##+XO X............++..+O@X...+ #@...XX........o@@# #o @O# OoO#@OO#X+XXo......",
+".......o+...X.o###X#o## O@@@#O #O#+.............+#@X. @........................@ o.....o........+##@o#X X## ###@o@#o+X.oX......",
+".......+#++.+X@#O#ooo# @#O#O Oo..............XO@o..#@....+X++Xo.....++........OoXX++..@.........@@@O#oOX#o ##Xo@@+XX+X@.......",
+"........XX+X+X@@X+#@o##OO@# oO##O...............oo++.++....X@....#+....++........ Oo..X..X..........#@#oo#oooooo+@o@.X+Xo+.......",
+".........#+++++++#X##o# OOO ##O #+..............o.+......+X......XO+....#+......+ #.....@+..........ooXXOo@oo@Xo.+@+XX+o+........",
+"..........o+.++@#o@oX@ OOoO oo@O+.............+X..X.......+.......@.....XX......X +.....o............OX+#oX@o@X@X+@++ooX.........",
+"..........XXX+oX@@o+XoOXO#@O@@##.............++...+.......o..Xo@#@X+......+.....+#.X@ooXX............o#Xooo+@@@++X+X+OX..........",
+"...........@X@X@XX+XX@o+# @#@XO...................X......@### O##.....+.......#o@@O OX+..........+ ooXo+X@X++@.o#+...........",
+"............oX@+++X+@#+Xo@+@+#@...................X......@ OOoO @.+X.....+......@@.# OO +...........oXo+XX+@X+.+@o.............",
+".............@..X@+X+o.XX@.++ ....................X......oO@.X # +.......+.......#o O#.#+...........+OX+..+.XXX@+..............",
+"..............o.X+o+Xo++X..+X ....................+......@++.@ O.X...............# o...............+ ###oX..................",
+"..............+o.+..X@XX@+++@o...................++......+#X..o O..X...............+ o@.Xo@.............o#.......................",
+"...............+@+.X@X@@X.+.X@...................@.........o@X.....X................+@+@@@..............XX+......................",
+".................oo@++.+++.+@+...................o..........+.@@@@...X...............ooX#@...............XX......................",
+"..................+#o..X....X...................+#..................X.................@.+XX...............o+.....................",
+"....................+X@#X++X@...................@X+.................+.................@+.oXX...............X.....................",
+".......................+@@o#@...................@X+...................................+@.X@o+..............X.....................",
+"...........................@...................X@X+....................................@X.o.o..............@+....................",
+"...........................@...................o.X+.....................................#.@..@+.............o.@o.................",
+"...........................o..................X+.X+.....................................@+X@..@o+...........@###.................",
+"...........................@................++@...+.....................................+oXo....o###...X+....# @.................",
+"..........................o@.................@....X.....................+XoX.............oXo......+@OOo+X@XX+O#..................",
+".........................o@................Xo+....+...................+o@@X@##............#o.........Xoo@@XX@+...................",
+"........................XX................+#+......+.................@@......+@+..........Xo...+XX...............................",
+"........................X+..............+Xo.........................@X.X+.......X+.........+#X#o++#..............................",
+"........................X+............+@@o..........................#.OOXX+.....+O X.........X....@X.............................",
+"........................o+..........+X+#@X..........................@@ X..+......+#OoX............+#.............................",
+".......................@o.......+..+#@o.+@..........................X@ ............X#O@............#.............................",
+"......................#X......+#oOOO@...X@..........................@X#..@ oo+.......+X+...........o+............................",
+".....................@X....+XX#.Xo+.....+@..........................X++..# #+@X.......+++..........X+............................",
+"....................XX....X@#@X@#........X+..............+X+.........X...+# O@@X.......+...........XX............................",
+"....................X..+o#@@X..X@........+@..............+X..................+@@X..................XX............................",
+"....................X.X##o#o...XX........@+..........................+........X@#..................#.............................",
+"....................@oX..X+....@........+@o..................XXX....+.........X+o+...............X#X.............................",
+"...............................@........@Xo....................@....+.........X.+X............++o @..............................",
+"...............................@........XXo.....................X..+.............+...........X#@ @...............................",
+"...............................X.........XoX....................@..X.......................+X##OX................................",
+"...............................X...........@+...................+X++.....................X@o###+.................................",
+"...............................X...........@X....................oX.....................@#@oo#X..................................",
+"...............................@...........+X.....................#X...................+@oX++#+..................................",
+"...............................@...........X@+....................Xo..........................oX.................................",
+"...............................X...........X+@@....................@+..........................#@................................",
+"...............................+X..........+++.@X...................#...........................oo...............................",
+"...............................+o.............@++X..................XO+.........................#+...............................",
+"................................o.............o..XX..................o#+...................+++X@@................................",
+"................................X+.............++X+X..................X@+........+.X@#O OO #X.................................",
+"................................XX................XXX..................+# O#@@o.XOOXX+XX@oO X...................................",
+".................................o...............@@++....................@#@X@o#o+.........+o....................................",
+".................................O..............+X+X........................XX+.............o....................................",
+".................................XX.............+@X.........................................@+...................................",
+"..................................@.............X.+.........................................X+...................................",
+"..................................@..............@X+........................................@+...................................",
+"..................................+@..............XXX@X......................+.+............#+...................................",
+"...................................X...............+X.Xo..............++....+.++@# O##OOOX....................................",
+"...................................XX...............+X.@X.............+X..+.X@O O oX..++.....................................",
+"....................................#.................X.@............++..oO#o #O X...........................................",
+".....................................@.................+o.....+........++#XoOOO#O@o#o............................................",
+".....................................@X................X....+++.........+++@@oo#..X#.............................................",
+"......................................@+..............X+.+..XX..............+.X...X#+............................................",
+".......................................@+............X..+.+.@X.+.++.........X.X....@o............................................",
+"........................................XX.............+.+..#.+.++...........+X.....#............................................",
+".........................................oo...........+X.+..#XX.@............+.X..+.X+...........................................",
+".........................................+oX............X.+.+OX.o..............X..+.XX...........................................",
+"..........................................+X+............+++.X@.X..............X+.+.#+...........................................",
+"...........................................+o............+XX..XX.o............+@+++XO............................................",
+"............................................+...............+..X.@X...........@X.X+#+............................................",
+".............................................................+++++@o+........@oXX@X+.............................................",
+".............................................................++..+X+@+....+X#@@@X................................................",
+"............................................................X.X..XX.++...+@#XXo..++++............................................",
+"..........................................................+X.X....@XXX..XXo+@@..+X...+...........................................",
+".........................................................+++X....+@@++.+XXXXoX.+X.....+..........................................",
+".........................................................X.+.....Xo@X.+XXX.oO..XXX+...+.+........................................",
+".........................................................+X......XX+X.++XXXOo.+#oO@+X.X@+........................................",
+".........................................................+X.....+++XX.++++oOX.oX##O@o@#@o........................................",
+"...........................................................++...+..XO++XXX@ +.#O# O #XXX........................................",
+"................................................................+...o#@+X+X +.o.@#oX@o...........................................",
+".................................................................X....X.@#.OX.+X#O X...........................................",
+"..................................................................++...+.XXXo+.+XoOoX............................................",
+".......................................................................++..+X@+..+XXX@@XX........................................",
+".........................................................................++..XXX+................................................",
+"................................................................................................................................."
+};
diff --git a/doc/groff.texinfo b/doc/groff.texinfo
index cee4e6dd..4c8c534c 100644
--- a/doc/groff.texinfo
+++ b/doc/groff.texinfo
@@ -9029,7 +9029,7 @@ The @code{als} request can make a macro have more than one name.
This would be called as
@Example
-.vl $Id: groff.texinfo,v 1.98 2002/02/05 07:10:09 wlemb Exp $
+.vl $Id: groff.texinfo,v 1.99 2002/02/10 01:22:09 wlemb Exp $
@endExample
@endDefesc
@@ -10653,7 +10653,7 @@ Requests that are missing non-optional arguments.
@item input
@itemx 16384
-Illegal input characters.
+Invalid input characters.
@item escape
@itemx 32768
diff --git a/doc/homepage.ms b/doc/homepage.ms
index 070c23dc..f9534902 100755
--- a/doc/homepage.ms
+++ b/doc/homepage.ms
@@ -5,26 +5,30 @@
.\" To make it work with other output devices also, we include www.tmac
.\" directly.
.mso www.tmac
+.
.defcolor darkred rgb 0.65f 0.1f 0.2f
.defcolor darkgreen rgb 0.1f 0.5f 0.2f
.defcolor darkblue rgb 0.1f 0.2f 0.6f
+.
.ds GNU \m[darkred]G\mP\m[darkgreen]N\mP\m[darkblue]U\mP
-.nr LL 8i
+.
.HTML-TL
Home of Groff (GNU Troff).
+.
.HTML-IMAGE-LEFT
-.PSPIC -L gnubw.eps 1i 1i
-\v'-0.5i'\h'1.0i'\s[50]\*[GNU] Troff\s0
+.PSPIC -L gnu.eps 1i 1i
+\v'-0.5i'\h'1.5i'\s[50]\*[GNU] Troff\s0
.HTML-IMAGE-END
+.
.sp
.LP
GNU Troff
-.URL (Groff) http://groff.ffii.org/
-\(em a
-.URL GNU http://www.gnu.org/
+.URL (Groff) http://\:groff.ffii.org/
+\[em] a
+.URL GNU http://\:www.gnu.org/
project.
Hosted by
-.URL FFII http://ffii.org/ .
+.URL FFII http://\:ffii.org/ .
.br
.LINE
.LINKS
@@ -35,25 +39,28 @@ formatting commands and produces formatted output.
Groff now supports HTML for the Web.
Please see
.URL "Groff Web Tips" "#Web Tips" .
-.sp
+.
+.
.SH
Download
.LP
-.URL Germany "ftp://groff.ffii.org/pub/groff/"
+.URL Germany "ftp://\:groff.ffii.org/\:pub/\:groff/"
|
-.URL USA "ftp://ftp.gnu.org/gnu/groff/"
+.URL USA "ftp://\:ftp.gnu.org/\:gnu/\:groff/"
.LP
-.URL License http://www.gnu.org/copyleft/gpl.html
+.URL License http://\:www.gnu.org/\:copyleft/\:gpl.html
|
-.URL "Mailing list" http://ffii.org/mailman/listinfo/groff/
+.URL "Mailing list" http://\:ffii.org/\:mailman/\:listinfo/\:groff/
|
-.URL "Groff for Windows" "http://www.cs.vu.nl/~tmgil/misc/wingroff.html"
+.URL "Groff for Windows" "http://\:www.cs.vu.nl/\:~tmgil/\:misc/\:wingroff.html"
.sp
User issues lead:
-.MAILTO Ted.Harding@nessie.mcc.ac.uk "Ted Harding"
+.MAILTO Ted.Harding@\:nessie.mcc.ac.uk "Ted Harding"
.br
Technical issues lead:
-.MAILTO wl@gnu.org "Werner Lemberg"
+.MAILTO wl@\:gnu.org "Werner Lemberg"
+.
+.
.SH
README
.LP
@@ -67,7 +74,7 @@ typewriter-like devices.
Also included is a modified version of the Berkeley -me macros, an enhanced
version of the X11 xditview previewer, and an implementation of the -mm
macros contributed by
-.MAILTO jh@axis.se "J\(:orgen H\(:agg" .
+.MAILTO jh@\:axis.se "J\(:orgen H\(:agg" .
.LP
See the file INSTALL for installation instructions.
You will require a C++ compiler.
@@ -84,7 +91,7 @@ For the moment, the documentation assumes that you are already familiar with
the Unix versions of troff, -man, -ms and the preprocessors.
.LP
The most recent released version of groff is always available by anonymous
-ftp from ftp.gnu.org in the directory pub/gnu/groff.
+ftp from ftp.gnu.org in the directory pub/\:gnu/\:groff.
.LP
A CVS repository is now available, containing the current development
version of groff.
@@ -92,11 +99,11 @@ You can access it with the commands:
.sp
.RS
.nf
-\fC
+.ft C
export CVSROOT=:pserver:anoncvs@anoncvs.ffii.org:/var/cvs
cvs login
cvs -z9 co groff
-\fR
+.ft P
.fi
.RE
.sp
@@ -106,9 +113,9 @@ After a successful login you no longer need the first two commands; an
update of a checked out repository should be done with:
.sp
.RS
-\fC
+.ft C
cvs -z9 update -dP
-\fR
+.ft P
.RE
.sp
.LP
@@ -116,13 +123,13 @@ Please read the info pages of cvs for further details.
.LP
Alternatively, you can download snapshots (which are updated twice a day)
from
-.URL here ftp://ftp.ffii.org/pub/groff/devel/groff-current.tar.gz
+.URL here ftp://\:ftp.ffii.org/\:pub/\:groff/\:devel/\:groff-current.tar.gz
or a diff file relative to the latest official groff release as:
.sp
.RS
-\fC
+.ft C
ftp://ftp.ffii.org/pub/groff/devel/groff-[version]-current.diff.gz
-\fR
+.ft P
.RE
.sp
.LP
@@ -138,31 +145,31 @@ Three mailing lists are available:
.sp
.RS
.nf
-\fC
+.ft C
bug-groff@gnu.org for reporting bugs
groff@gnu.org for general discussion of groff
groff-commit@ffii.org a read-only list showing logs of
commitments to the CVS repository
-\fP
+.ft P
.fi
.RE
.sp
.LP
Note that groff@gnu.org is an alias for
-.MAILTO groff@ffii.org groff@ffii.org ;
+.MAILTO groff@\:ffii.org groff@\:ffii.org ;
you must be subscribed to the `groff' and `groff-commit' lists to send mails.
.LP
To subscribe, send e-mail to [list]-request@[domain] (example:
-.MAILTO groff-request@ffii.org groff-request@ffii.org )
+.MAILTO groff-request@\:ffii.org groff-request@\:ffii.org )
with the word `subscribe' in either the
subject or body of the e-mail (don't include the quotes).
.LP
GNU groff was written by
-.MAILTO jjc@jclark.com "James Clark" .
+.MAILTO jjc@\:jclark.com "James Clark" .
It is now maintained by
-.MAILTO Ted.Harding@nessie.mcc.ac.uk "Ted Harding"
+.MAILTO Ted.Harding@\:nessie.mcc.ac.uk "Ted Harding"
and
-.MAILTO wl@gnu.org "Werner Lemberg" .
+.MAILTO wl@\:gnu.org "Werner Lemberg" .
.br
.
.\" EOF
diff --git a/src/devices/grops/psrm.cc b/src/devices/grops/psrm.cc
index 5f232c02..21b95244 100644
--- a/src/devices/grops/psrm.cc
+++ b/src/devices/grops/psrm.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
@@ -389,7 +389,7 @@ static int ps_get_line(char *buf, FILE *fp)
int err = 0;
while (c != '\r' && c != '\n' && c != EOF) {
if ((c < 0x1b && !white_space(c)) || c == 0x7f)
- error("illegal input character code %1", int(c));
+ error("invalid input character code %1", int(c));
else if (i < PS_LINE_MAX)
buf[i++] = c;
else if (!err) {
diff --git a/src/include/lib.h b/src/include/lib.h
index f785d481..48129af0 100644
--- a/src/include/lib.h
+++ b/src/include/lib.h
@@ -74,11 +74,11 @@ size_t file_name_max(const char *fname);
int interpret_lf_args(const char *p);
-extern char illegal_char_table[];
+extern char invalid_char_table[];
-inline int illegal_input_char(int c)
+inline int invalid_input_char(int c)
{
- return c >= 0 && illegal_char_table[c];
+ return c >= 0 && invalid_char_table[c];
}
#ifdef HAVE_STRCASECMP
diff --git a/src/libs/libgroff/Makefile.sub b/src/libs/libgroff/Makefile.sub
index e3d3337a..300e41c0 100644
--- a/src/libs/libgroff/Makefile.sub
+++ b/src/libs/libgroff/Makefile.sub
@@ -16,7 +16,7 @@ OBJS=\
getopt.o \
getopt1.o \
htmlhint.o \
- illegal.o \
+ invalid.o \
lf.o \
lineno.o \
macropath.o \
@@ -52,7 +52,7 @@ CCSRCS=\
$(srcdir)/fontfile.cc \
$(srcdir)/geometry.cc \
$(srcdir)/htmlhint.cc \
- $(srcdir)/illegal.cc \
+ $(srcdir)/invalid.cc \
$(srcdir)/lf.cc \
$(srcdir)/lineno.cc \
$(srcdir)/macropath.cc \
diff --git a/src/libs/libgroff/font.cc b/src/libs/libgroff/font.cc
index 0e28d4b5..fe107b20 100644
--- a/src/libs/libgroff/font.cc
+++ b/src/libs/libgroff/font.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
@@ -93,7 +93,6 @@ text_file::~text_file()
fclose(fp);
}
-
int text_file::next()
{
if (fp == 0)
@@ -108,8 +107,8 @@ int text_file::next()
int c = getc(fp);
if (c == EOF)
break;
- if (illegal_input_char(c))
- error("illegal input character code `%1'", int(c));
+ if (invalid_input_char(c))
+ error("invalid input character code `%1'", int(c));
else {
if (i + 1 >= size) {
char *old_buf = buf;
@@ -585,12 +584,12 @@ int font::load(int *not_found)
}
int i1 = name_to_index(c1);
if (i1 < 0) {
- t.error("illegal character `%1'", c1);
+ t.error("invalid character `%1'", c1);
return 0;
}
int i2 = name_to_index(c2);
if (i2 < 0) {
- t.error("illegal character `%1'", c2);
+ t.error("invalid character `%1'", c2);
return 0;
}
add_kern(i1, i2, n);
@@ -623,7 +622,7 @@ int font::load(int *not_found)
}
int index = name_to_index(nm);
if (index < 0) {
- t.error("illegal character `%1'", nm);
+ t.error("invalid character `%1'", nm);
return 0;
}
copy_entry(index, last_index);
@@ -691,7 +690,7 @@ int font::load(int *not_found)
else {
last_index = name_to_index(nm);
if (last_index < 0) {
- t.error("illegal character `%1'", nm);
+ t.error("invalid character `%1'", nm);
return 0;
}
add_entry(last_index, metric);
diff --git a/src/preproc/eqn/eqn.cc b/src/preproc/eqn/eqn.cc
deleted file mode 100755
index 1fdda611..00000000
--- a/src/preproc/eqn/eqn.cc
+++ /dev/null
@@ -1,1277 +0,0 @@
-#if defined(__STDC__) || defined(__cplusplus)
-#define YYCONST const
-#define YYPARAMS(x) x
-#define YYDEFUN(name, arglist, args) name(args)
-#define YYAND ,
-#define YYPTR void *
-#else
-#define YYCONST
-#define YYPARAMS(x) ()
-#define YYDEFUN(name, arglist, args) name arglist args;
-#define YYAND ;
-#define YYPTR char *
-#endif
-#ifndef lint
-YYCONST static char yysccsid[] = "@(#)yaccpar 1.8 (Berkeley +Cygnus.28) 01/20/91";
-#endif
-#define YYBYACC 1
-#ifndef YYDONT_INCLUDE_STDIO
-#include <stdio.h>
-#endif
-#ifdef __cplusplus
-#include <stdlib.h> /* for malloc/realloc/free */
-#endif
-#line 20 "eqn.y"
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-
-#include "lib.h"
-#include "box.h"
-extern int non_empty_flag;
-char *strsave(const char *);
-int yylex();
-void yyerror(const char *);
-#line 32 "eqn.y"
-typedef union {
- char *str;
- box *b;
- pile_box *pb;
- matrix_box *mb;
- int n;
- column *col;
-} YYSTYPE;
-#line 45 "y.tab.c"
-#define OVER 257
-#define SMALLOVER 258
-#define SQRT 259
-#define SUB 260
-#define SUP 261
-#define LPILE 262
-#define RPILE 263
-#define CPILE 264
-#define PILE 265
-#define LEFT 266
-#define RIGHT 267
-#define TO 268
-#define FROM 269
-#define SIZE 270
-#define FONT 271
-#define ROMAN 272
-#define BOLD 273
-#define ITALIC 274
-#define FAT 275
-#define ACCENT 276
-#define BAR 277
-#define UNDER 278
-#define ABOVE 279
-#define TEXT 280
-#define QUOTED_TEXT 281
-#define FWD 282
-#define BACK 283
-#define DOWN 284
-#define UP 285
-#define MATRIX 286
-#define COL 287
-#define LCOL 288
-#define RCOL 289
-#define CCOL 290
-#define MARK 291
-#define LINEUP 292
-#define TYPE 293
-#define VCENTER 294
-#define PRIME 295
-#define SPLIT 296
-#define NOSPLIT 297
-#define UACCENT 298
-#define SPECIAL 299
-#define SPACE 300
-#define GFONT 301
-#define GSIZE 302
-#define DEFINE 303
-#define NDEFINE 304
-#define TDEFINE 305
-#define SDEFINE 306
-#define UNDEF 307
-#define IFDEF 308
-#define INCLUDE 309
-#define DELIM 310
-#define CHARTYPE 311
-#define SET 312
-#define GRFONT 313
-#define GBFONT 314
-#define YYERRCODE 256
-static YYCONST short yylhs[] = { -1,
- 0, 0, 6, 6, 1, 1, 1, 2, 2, 2,
- 2, 2, 3, 3, 3, 3, 4, 4, 7, 7,
- 7, 5, 5, 5, 5, 5, 5, 5, 5, 5,
- 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
- 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
- 5, 5, 5, 5, 8, 11, 11, 12, 12, 13,
- 13, 16, 16, 15, 15, 14, 14, 14, 14, 9,
- 9, 10, 10, 10,
-};
-static YYCONST short yylen[] = { 2,
- 0, 1, 1, 2, 1, 2, 2, 1, 3, 3,
- 5, 5, 1, 2, 3, 3, 1, 3, 1, 3,
- 5, 1, 1, 2, 2, 1, 1, 1, 3, 2,
- 2, 2, 2, 4, 5, 3, 2, 2, 2, 3,
- 3, 2, 2, 2, 2, 3, 3, 3, 3, 3,
- 3, 3, 2, 3, 1, 1, 3, 3, 4, 1,
- 2, 1, 3, 3, 4, 2, 2, 2, 2, 1,
- 1, 1, 1, 1,
-};
-static YYCONST short yydefred[] = { 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 22, 23, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 26, 27, 28, 0,
- 0, 3, 5, 0, 13, 0, 0, 17, 14, 70,
- 71, 0, 0, 55, 31, 32, 33, 30, 73, 74,
- 72, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 6, 7, 0, 0, 24, 25, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 37, 38,
- 39, 0, 4, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 60, 0,
- 0, 29, 15, 16, 9, 0, 0, 20, 18, 40,
- 41, 0, 58, 0, 0, 0, 0, 66, 67, 68,
- 69, 34, 61, 0, 0, 0, 0, 59, 35, 0,
- 0, 0, 11, 12, 21, 0, 64, 0, 0, 65,
-};
-static YYCONST short yydgoto[] = { 31,
- 32, 33, 34, 35, 36, 84, 38, 43, 44, 52,
- 85, 45, 98, 99, 118, 131,
-};
-static YYCONST short yysindex[] = { 1488,
- 1527, -120, -120, -120, -120, -123, -249, -249, 1566, 1566,
- 1566, 1566, 0, 0, -249, -249, -249, -249, -115, 1488,
- 1488, -249, 1566, -256, -251, -249, 0, 0, 0, 1488,
- 0, 0, 0, -221, 0, -233, 1488, 0, 0, 0,
- 0, 1488, -85, 0, 0, 0, 0, 0, 0, 0,
- 0, 1488, 1566, 1566, -195, -195, -195, -195, 1566, 1566,
- 1566, 1566, -272, 0, 0, 1566, -195, 0, 0, 1566,
- 1402, 1527, 1527, 1527, 1527, 1566, 1566, 1566, 0, 0,
- 0, 1566, 0, 1488, -113, 1488, 1444, -195, -195, -195,
- -195, -195, -195, -117, -117, -117, -117, -118, 0, -195,
- -195, 0, 0, 0, 0, -167, -189, 0, 0, 0,
- 0, 1488, 0, -106, -123, 1488, -83, 0, 0, 0,
- 0, 0, 0, 1527, 1527, 1566, 1488, 0, 0, 1488,
- -105, 1488, 0, 0, 0, 1488, 0, -104, 1488, 0,
-};
-static YYCONST short yyrindex[] = { 41,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 1, 0, 1220, 46, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 85, 128, 363, 406, 0, 0,
- 0, 0, 0, 0, 0, 0, 449, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, -103, 0, 0, 185, 492, 727, 770,
- 813, 856, 1091, 0, 0, 0, 0, 0, 0, 1134,
- 1177, 0, 0, 0, 0, 42, 1220, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, -102, 0, 0, -101,
- 0, 0, 0, 0, 0, 0, 0, 0, -99, 0,
-};
-static YYCONST short yygindex[] = { 0,
- -7, -69, 3, -66, 458, 9, -26, 52, 27, -63,
- -32, 54, 0, -35, 2, -59,
-};
-#define YYTABLESIZE 1865
-static YYCONST short yytable[] = { 49,
- 8, 50, 42, 39, 105, 116, 122, 63, 37, 8,
- 109, 113, 64, 65, 94, 95, 96, 97, 128, 137,
- 140, 56, 57, 62, 68, 63, 76, 77, 69, 83,
- 40, 41, 51, 53, 54, 72, 73, 86, 71, 132,
- 1, 10, 78, 79, 80, 2, 74, 75, 66, 108,
- 10, 129, 70, 114, 133, 134, 46, 47, 48, 135,
- 87, 81, 123, 83, 82, 0, 59, 60, 61, 62,
- 76, 126, 138, 0, 103, 104, 83, 106, 0, 83,
- 78, 79, 80, 0, 42, 0, 78, 79, 80, 72,
- 73, 0, 0, 42, 8, 0, 119, 120, 121, 81,
- 124, 125, 82, 0, 0, 81, 0, 0, 82, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 83,
- 127, 0, 83, 8, 130, 8, 8, 43, 0, 0,
- 0, 83, 0, 0, 0, 10, 43, 0, 0, 0,
- 130, 51, 0, 0, 139, 117, 117, 117, 117, 0,
- 0, 0, 0, 0, 0, 0, 40, 41, 0, 40,
- 41, 0, 40, 41, 10, 112, 10, 10, 94, 95,
- 96, 97, 112, 136, 136, 56, 57, 62, 42, 63,
- 0, 0, 0, 0, 36, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 42, 0, 42,
- 42, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 43, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 43, 0, 43, 43, 0, 0, 0, 0, 0, 8,
- 8, 8, 8, 8, 8, 8, 8, 8, 0, 0,
- 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
- 8, 8, 8, 8, 8, 8, 8, 0, 0, 0,
- 0, 8, 8, 8, 8, 8, 8, 8, 8, 8,
- 10, 10, 10, 10, 10, 10, 10, 10, 10, 36,
- 0, 10, 10, 10, 10, 10, 10, 10, 10, 10,
- 10, 10, 10, 10, 10, 10, 10, 10, 0, 0,
- 0, 0, 10, 10, 10, 10, 10, 10, 10, 10,
- 10, 42, 42, 42, 42, 42, 42, 42, 42, 42,
- 42, 42, 42, 42, 42, 42, 42, 42, 42, 42,
- 0, 0, 44, 42, 42, 42, 42, 42, 42, 42,
- 42, 44, 0, 0, 0, 42, 42, 42, 42, 0,
- 42, 42, 0, 42, 43, 43, 43, 43, 43, 43,
- 43, 43, 43, 43, 43, 43, 43, 43, 43, 43,
- 43, 43, 43, 0, 0, 45, 43, 43, 43, 43,
- 43, 43, 43, 43, 45, 0, 0, 0, 43, 43,
- 43, 43, 0, 43, 43, 0, 43, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 36, 36, 0, 36, 36, 0, 0, 53, 0,
- 0, 0, 36, 36, 0, 0, 44, 53, 0, 0,
- 36, 36, 36, 36, 0, 0, 55, 56, 57, 58,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 36,
- 67, 0, 36, 0, 0, 44, 0, 44, 44, 0,
- 0, 47, 0, 0, 0, 0, 0, 0, 0, 45,
- 47, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 88, 89, 0, 0, 0, 0, 90, 91, 92, 93,
- 0, 0, 0, 100, 0, 0, 0, 101, 45, 0,
- 45, 45, 0, 107, 0, 110, 0, 0, 0, 111,
- 0, 0, 53, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 53, 0, 53, 53, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 47, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 47, 0, 47, 47, 0, 44,
- 44, 44, 44, 44, 44, 44, 44, 44, 44, 44,
- 44, 44, 44, 44, 44, 44, 44, 44, 0, 0,
- 0, 44, 44, 44, 44, 44, 44, 44, 44, 0,
- 0, 0, 0, 44, 44, 44, 44, 0, 44, 44,
- 0, 44, 45, 45, 45, 45, 45, 45, 45, 45,
- 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
- 45, 0, 0, 0, 45, 45, 45, 45, 45, 45,
- 45, 45, 0, 0, 0, 0, 45, 45, 45, 45,
- 0, 45, 45, 0, 45, 53, 53, 53, 53, 53,
- 53, 53, 53, 53, 53, 53, 53, 53, 53, 53,
- 53, 53, 53, 53, 0, 0, 46, 53, 53, 53,
- 53, 53, 53, 53, 53, 46, 0, 0, 0, 53,
- 53, 53, 53, 0, 53, 53, 0, 53, 47, 47,
- 47, 47, 47, 47, 47, 47, 47, 47, 47, 47,
- 47, 47, 47, 47, 47, 47, 47, 0, 0, 48,
- 47, 47, 47, 47, 47, 47, 47, 47, 48, 0,
- 0, 0, 47, 47, 47, 47, 0, 47, 47, 0,
- 47, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 49, 0, 0, 0, 0, 0, 0, 0,
- 46, 49, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 46,
- 0, 46, 46, 0, 0, 51, 0, 0, 0, 0,
- 0, 0, 0, 48, 51, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 48, 0, 48, 48, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 49, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 49, 0, 49, 49, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 51,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 51, 0,
- 51, 51, 0, 46, 46, 46, 46, 46, 46, 46,
- 46, 46, 46, 46, 46, 46, 46, 46, 46, 46,
- 46, 46, 0, 0, 0, 46, 46, 46, 46, 46,
- 46, 46, 46, 0, 0, 0, 0, 46, 46, 46,
- 46, 0, 46, 46, 0, 46, 48, 48, 48, 48,
- 48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
- 48, 48, 48, 48, 48, 0, 0, 0, 48, 48,
- 48, 48, 48, 48, 48, 48, 0, 0, 0, 0,
- 48, 48, 48, 48, 0, 48, 48, 0, 48, 49,
- 49, 49, 49, 49, 49, 49, 49, 49, 49, 49,
- 49, 49, 49, 49, 49, 49, 49, 49, 0, 0,
- 50, 49, 49, 49, 49, 49, 49, 49, 49, 50,
- 0, 0, 0, 49, 49, 49, 49, 0, 49, 49,
- 0, 49, 51, 51, 51, 51, 51, 51, 51, 51,
- 51, 51, 51, 51, 51, 51, 51, 51, 51, 51,
- 51, 0, 0, 52, 51, 51, 51, 51, 51, 51,
- 51, 51, 52, 0, 0, 0, 51, 51, 51, 51,
- 0, 51, 51, 0, 51, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 54, 0, 0, 0,
- 0, 0, 0, 0, 50, 54, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 50, 0, 50, 50, 0, 0, 19,
- 0, 0, 0, 0, 0, 0, 0, 52, 19, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 52, 0, 52, 52,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 54, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 54,
- 0, 54, 54, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 19, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 19, 0, 19, 19, 0, 50, 50, 50,
- 50, 50, 50, 50, 50, 50, 50, 50, 50, 50,
- 50, 50, 50, 50, 50, 50, 0, 0, 0, 50,
- 50, 50, 50, 50, 50, 50, 50, 0, 0, 0,
- 0, 50, 50, 50, 50, 0, 50, 50, 0, 50,
- 52, 52, 52, 52, 52, 52, 52, 52, 52, 52,
- 52, 52, 52, 52, 52, 52, 52, 52, 52, 0,
- 29, 0, 52, 52, 52, 52, 52, 52, 52, 52,
- 0, 0, 0, 0, 52, 52, 52, 52, 0, 52,
- 52, 0, 52, 54, 54, 54, 54, 54, 54, 54,
- 54, 54, 54, 54, 54, 54, 54, 54, 54, 54,
- 54, 54, 29, 0, 0, 54, 54, 54, 54, 54,
- 54, 54, 54, 0, 0, 0, 0, 54, 54, 54,
- 54, 0, 54, 54, 0, 54, 19, 19, 19, 0,
- 0, 19, 19, 19, 19, 19, 19, 19, 19, 19,
- 19, 19, 19, 19, 19, 27, 29, 0, 19, 19,
- 19, 19, 19, 19, 19, 19, 0, 0, 0, 0,
- 19, 19, 19, 19, 0, 19, 19, 0, 19, 0,
- 0, 0, 0, 0, 30, 0, 102, 28, 0, 0,
- 0, 0, 0, 0, 0, 29, 0, 27, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 30, 0, 0, 28,
- 0, 0, 0, 0, 29, 0, 0, 0, 0, 0,
- 0, 27, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 30, 0, 0, 28, 0, 0, 0, 0, 0, 0,
- 27, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 30,
- 0, 0, 28, 0, 0, 0, 0, 0, 0, 27,
- 1, 0, 0, 2, 3, 4, 5, 6, 0, 0,
- 0, 7, 8, 9, 10, 11, 12, 0, 0, 0,
- 0, 13, 14, 15, 16, 17, 18, 19, 30, 0,
- 0, 28, 20, 21, 22, 23, 0, 24, 25, 0,
- 26, 0, 1, 0, 0, 2, 3, 4, 5, 6,
- 115, 0, 0, 7, 8, 9, 10, 11, 12, 0,
- 0, 0, 0, 13, 14, 15, 16, 17, 18, 19,
- 0, 0, 0, 0, 20, 21, 22, 23, 0, 24,
- 25, 0, 26, 0, 0, 0, 1, 0, 0, 2,
- 3, 4, 5, 6, 0, 0, 0, 7, 8, 9,
- 10, 11, 12, 0, 0, 0, 0, 13, 14, 15,
- 16, 17, 18, 19, 0, 0, 0, 0, 20, 21,
- 22, 23, 0, 24, 25, 1, 26, 0, 2, 3,
- 4, 5, 6, 0, 0, 0, 7, 8, 9, 10,
- 11, 12, 0, 0, 0, 0, 13, 14, 15, 16,
- 17, 18, 19, 0, 0, 0, 0, 0, 0, 22,
- 23, 0, 24, 25, 0, 26, 0, 2, 3, 4,
- 5, 6, 0, 0, 0, 7, 8, 9, 10, 11,
- 12, 0, 0, 0, 0, 13, 14, 15, 16, 17,
- 18, 19, 0, 0, 0, 0, 0, 0, 22, 23,
- 0, 24, 25, 0, 26,
-};
-static YYCONST short yycheck[] = { 123,
- 0, 125, 123, 1, 74, 123, 125, 123, 0, 9,
- 77, 125, 20, 21, 287, 288, 289, 290, 125, 125,
- 125, 125, 125, 125, 281, 125, 260, 261, 280, 37,
- 280, 281, 6, 7, 8, 257, 258, 123, 30, 123,
- 0, 0, 276, 277, 278, 0, 268, 269, 22, 76,
- 9, 115, 26, 86, 124, 125, 3, 4, 5, 126,
- 52, 295, 98, 71, 298, -1, 15, 16, 17, 18,
- 260, 261, 132, -1, 72, 73, 84, 75, -1, 87,
- 276, 277, 278, -1, 0, -1, 276, 277, 278, 257,
- 258, -1, -1, 9, 94, -1, 95, 96, 97, 295,
- 268, 269, 298, -1, -1, 295, -1, -1, 298, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 127,
- 112, -1, 130, 123, 116, 125, 126, 0, -1, -1,
- -1, 139, -1, -1, -1, 94, 9, -1, -1, -1,
- 132, 115, -1, -1, 136, 94, 95, 96, 97, -1,
- -1, -1, -1, -1, -1, -1, 280, 281, -1, 280,
- 281, -1, 280, 281, 123, 279, 125, 126, 287, 288,
- 289, 290, 279, 279, 279, 279, 279, 279, 94, 279,
- -1, -1, -1, -1, 0, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, 123, -1, 125,
- 126, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, 94, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- 123, -1, 125, 126, -1, -1, -1, -1, -1, 259,
- 260, 261, 262, 263, 264, 265, 266, 267, -1, -1,
- 270, 271, 272, 273, 274, 275, 276, 277, 278, 279,
- 280, 281, 282, 283, 284, 285, 286, -1, -1, -1,
- -1, 291, 292, 293, 294, 295, 296, 297, 298, 299,
- 259, 260, 261, 262, 263, 264, 265, 266, 267, 125,
- -1, 270, 271, 272, 273, 274, 275, 276, 277, 278,
- 279, 280, 281, 282, 283, 284, 285, 286, -1, -1,
- -1, -1, 291, 292, 293, 294, 295, 296, 297, 298,
- 299, 257, 258, 259, 260, 261, 262, 263, 264, 265,
- 266, 267, 268, 269, 270, 271, 272, 273, 274, 275,
- -1, -1, 0, 279, 280, 281, 282, 283, 284, 285,
- 286, 9, -1, -1, -1, 291, 292, 293, 294, -1,
- 296, 297, -1, 299, 257, 258, 259, 260, 261, 262,
- 263, 264, 265, 266, 267, 268, 269, 270, 271, 272,
- 273, 274, 275, -1, -1, 0, 279, 280, 281, 282,
- 283, 284, 285, 286, 9, -1, -1, -1, 291, 292,
- 293, 294, -1, 296, 297, -1, 299, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, 257, 258, -1, 260, 261, -1, -1, 0, -1,
- -1, -1, 268, 269, -1, -1, 94, 9, -1, -1,
- 276, 277, 278, 279, -1, -1, 9, 10, 11, 12,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 295,
- 23, -1, 298, -1, -1, 123, -1, 125, 126, -1,
- -1, 0, -1, -1, -1, -1, -1, -1, -1, 94,
- 9, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- 53, 54, -1, -1, -1, -1, 59, 60, 61, 62,
- -1, -1, -1, 66, -1, -1, -1, 70, 123, -1,
- 125, 126, -1, 76, -1, 78, -1, -1, -1, 82,
- -1, -1, 94, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, 123, -1, 125, 126, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, 94, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, 123, -1, 125, 126, -1, 257,
- 258, 259, 260, 261, 262, 263, 264, 265, 266, 267,
- 268, 269, 270, 271, 272, 273, 274, 275, -1, -1,
- -1, 279, 280, 281, 282, 283, 284, 285, 286, -1,
- -1, -1, -1, 291, 292, 293, 294, -1, 296, 297,
- -1, 299, 257, 258, 259, 260, 261, 262, 263, 264,
- 265, 266, 267, 268, 269, 270, 271, 272, 273, 274,
- 275, -1, -1, -1, 279, 280, 281, 282, 283, 284,
- 285, 286, -1, -1, -1, -1, 291, 292, 293, 294,
- -1, 296, 297, -1, 299, 257, 258, 259, 260, 261,
- 262, 263, 264, 265, 266, 267, 268, 269, 270, 271,
- 272, 273, 274, 275, -1, -1, 0, 279, 280, 281,
- 282, 283, 284, 285, 286, 9, -1, -1, -1, 291,
- 292, 293, 294, -1, 296, 297, -1, 299, 257, 258,
- 259, 260, 261, 262, 263, 264, 265, 266, 267, 268,
- 269, 270, 271, 272, 273, 274, 275, -1, -1, 0,
- 279, 280, 281, 282, 283, 284, 285, 286, 9, -1,
- -1, -1, 291, 292, 293, 294, -1, 296, 297, -1,
- 299, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, 0, -1, -1, -1, -1, -1, -1, -1,
- 94, 9, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 123,
- -1, 125, 126, -1, -1, 0, -1, -1, -1, -1,
- -1, -1, -1, 94, 9, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, 123, -1, 125, 126, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, 94, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, 123, -1, 125, 126, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 94,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, 123, -1,
- 125, 126, -1, 257, 258, 259, 260, 261, 262, 263,
- 264, 265, 266, 267, 268, 269, 270, 271, 272, 273,
- 274, 275, -1, -1, -1, 279, 280, 281, 282, 283,
- 284, 285, 286, -1, -1, -1, -1, 291, 292, 293,
- 294, -1, 296, 297, -1, 299, 257, 258, 259, 260,
- 261, 262, 263, 264, 265, 266, 267, 268, 269, 270,
- 271, 272, 273, 274, 275, -1, -1, -1, 279, 280,
- 281, 282, 283, 284, 285, 286, -1, -1, -1, -1,
- 291, 292, 293, 294, -1, 296, 297, -1, 299, 257,
- 258, 259, 260, 261, 262, 263, 264, 265, 266, 267,
- 268, 269, 270, 271, 272, 273, 274, 275, -1, -1,
- 0, 279, 280, 281, 282, 283, 284, 285, 286, 9,
- -1, -1, -1, 291, 292, 293, 294, -1, 296, 297,
- -1, 299, 257, 258, 259, 260, 261, 262, 263, 264,
- 265, 266, 267, 268, 269, 270, 271, 272, 273, 274,
- 275, -1, -1, 0, 279, 280, 281, 282, 283, 284,
- 285, 286, 9, -1, -1, -1, 291, 292, 293, 294,
- -1, 296, 297, -1, 299, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, 0, -1, -1, -1,
- -1, -1, -1, -1, 94, 9, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, 123, -1, 125, 126, -1, -1, 0,
- -1, -1, -1, -1, -1, -1, -1, 94, 9, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, 123, -1, 125, 126,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- 94, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 123,
- -1, 125, 126, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, 94, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, 123, -1, 125, 126, -1, 257, 258, 259,
- 260, 261, 262, 263, 264, 265, 266, 267, 268, 269,
- 270, 271, 272, 273, 274, 275, -1, -1, -1, 279,
- 280, 281, 282, 283, 284, 285, 286, -1, -1, -1,
- -1, 291, 292, 293, 294, -1, 296, 297, -1, 299,
- 257, 258, 259, 260, 261, 262, 263, 264, 265, 266,
- 267, 268, 269, 270, 271, 272, 273, 274, 275, -1,
- 9, -1, 279, 280, 281, 282, 283, 284, 285, 286,
- -1, -1, -1, -1, 291, 292, 293, 294, -1, 296,
- 297, -1, 299, 257, 258, 259, 260, 261, 262, 263,
- 264, 265, 266, 267, 268, 269, 270, 271, 272, 273,
- 274, 275, 9, -1, -1, 279, 280, 281, 282, 283,
- 284, 285, 286, -1, -1, -1, -1, 291, 292, 293,
- 294, -1, 296, 297, -1, 299, 257, 258, 259, -1,
- -1, 262, 263, 264, 265, 266, 267, 268, 269, 270,
- 271, 272, 273, 274, 275, 94, 9, -1, 279, 280,
- 281, 282, 283, 284, 285, 286, -1, -1, -1, -1,
- 291, 292, 293, 294, -1, 296, 297, -1, 299, -1,
- -1, -1, -1, -1, 123, -1, 125, 126, -1, -1,
- -1, -1, -1, -1, -1, 9, -1, 94, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, 123, -1, -1, 126,
- -1, -1, -1, -1, 9, -1, -1, -1, -1, -1,
- -1, 94, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- 123, -1, -1, 126, -1, -1, -1, -1, -1, -1,
- 94, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
- -1, -1, -1, -1, -1, -1, -1, -1, -1, 123,
- -1, -1, 126, -1, -1, -1, -1, -1, -1, 94,
- 259, -1, -1, 262, 263, 264, 265, 266, -1, -1,
- -1, 270, 271, 272, 273, 274, 275, -1, -1, -1,
- -1, 280, 281, 282, 283, 284, 285, 286, 123, -1,
- -1, 126, 291, 292, 293, 294, -1, 296, 297, -1,
- 299, -1, 259, -1, -1, 262, 263, 264, 265, 266,
- 267, -1, -1, 270, 271, 272, 273, 274, 275, -1,
- -1, -1, -1, 280, 281, 282, 283, 284, 285, 286,
- -1, -1, -1, -1, 291, 292, 293, 294, -1, 296,
- 297, -1, 299, -1, -1, -1, 259, -1, -1, 262,
- 263, 264, 265, 266, -1, -1, -1, 270, 271, 272,
- 273, 274, 275, -1, -1, -1, -1, 280, 281, 282,
- 283, 284, 285, 286, -1, -1, -1, -1, 291, 292,
- 293, 294, -1, 296, 297, 259, 299, -1, 262, 263,
- 264, 265, 266, -1, -1, -1, 270, 271, 272, 273,
- 274, 275, -1, -1, -1, -1, 280, 281, 282, 283,
- 284, 285, 286, -1, -1, -1, -1, -1, -1, 293,
- 294, -1, 296, 297, -1, 299, -1, 262, 263, 264,
- 265, 266, -1, -1, -1, 270, 271, 272, 273, 274,
- 275, -1, -1, -1, -1, 280, 281, 282, 283, 284,
- 285, 286, -1, -1, -1, -1, -1, -1, 293, 294,
- -1, 296, 297, -1, 299,
-};
-#define YYFINAL 31
-#ifndef YYDEBUG
-#define YYDEBUG 0
-#endif
-#define YYMAXTOKEN 314
-#if YYDEBUG
-static YYCONST char *YYCONST yyname[] = {
-"end-of-file",0,0,0,0,0,0,0,0,"'\\t'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'^'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'","'~'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"OVER",
-"SMALLOVER","SQRT","SUB","SUP","LPILE","RPILE","CPILE","PILE","LEFT","RIGHT",
-"TO","FROM","SIZE","FONT","ROMAN","BOLD","ITALIC","FAT","ACCENT","BAR","UNDER",
-"ABOVE","TEXT","QUOTED_TEXT","FWD","BACK","DOWN","UP","MATRIX","COL","LCOL",
-"RCOL","CCOL","MARK","LINEUP","TYPE","VCENTER","PRIME","SPLIT","NOSPLIT",
-"UACCENT","SPECIAL","SPACE","GFONT","GSIZE","DEFINE","NDEFINE","TDEFINE",
-"SDEFINE","UNDEF","IFDEF","INCLUDE","DELIM","CHARTYPE","SET","GRFONT","GBFONT",
-};
-static YYCONST char *YYCONST yyrule[] = {
-"$accept : top",
-"top :",
-"top : equation",
-"equation : mark",
-"equation : equation mark",
-"mark : from_to",
-"mark : MARK mark",
-"mark : LINEUP mark",
-"from_to : sqrt_over",
-"from_to : sqrt_over TO from_to",
-"from_to : sqrt_over FROM sqrt_over",
-"from_to : sqrt_over FROM sqrt_over TO from_to",
-"from_to : sqrt_over FROM sqrt_over FROM from_to",
-"sqrt_over : script",
-"sqrt_over : SQRT sqrt_over",
-"sqrt_over : sqrt_over OVER sqrt_over",
-"sqrt_over : sqrt_over SMALLOVER sqrt_over",
-"script : nonsup",
-"script : simple SUP script",
-"nonsup : simple",
-"nonsup : simple SUB nonsup",
-"nonsup : simple SUB simple SUP script",
-"simple : TEXT",
-"simple : QUOTED_TEXT",
-"simple : SPLIT QUOTED_TEXT",
-"simple : NOSPLIT TEXT",
-"simple : '^'",
-"simple : '~'",
-"simple : '\\t'",
-"simple : '{' equation '}'",
-"simple : PILE pile_arg",
-"simple : LPILE pile_arg",
-"simple : RPILE pile_arg",
-"simple : CPILE pile_arg",
-"simple : MATRIX '{' column_list '}'",
-"simple : LEFT delim equation RIGHT delim",
-"simple : LEFT delim equation",
-"simple : simple BAR",
-"simple : simple UNDER",
-"simple : simple PRIME",
-"simple : simple ACCENT simple",
-"simple : simple UACCENT simple",
-"simple : ROMAN simple",
-"simple : BOLD simple",
-"simple : ITALIC simple",
-"simple : FAT simple",
-"simple : FONT text simple",
-"simple : SIZE text simple",
-"simple : FWD number simple",
-"simple : BACK number simple",
-"simple : UP number simple",
-"simple : DOWN number simple",
-"simple : TYPE text simple",
-"simple : VCENTER simple",
-"simple : SPECIAL text simple",
-"number : text",
-"pile_element_list : equation",
-"pile_element_list : pile_element_list ABOVE equation",
-"pile_arg : '{' pile_element_list '}'",
-"pile_arg : number '{' pile_element_list '}'",
-"column_list : column",
-"column_list : column_list column",
-"column_element_list : equation",
-"column_element_list : column_element_list ABOVE equation",
-"column_arg : '{' column_element_list '}'",
-"column_arg : number '{' column_element_list '}'",
-"column : COL column_arg",
-"column : LCOL column_arg",
-"column : RCOL column_arg",
-"column : CCOL column_arg",
-"text : TEXT",
-"text : QUOTED_TEXT",
-"delim : text",
-"delim : '{'",
-"delim : '}'",
-};
-#endif
-#define YYLEX yylex()
-#define YYEMPTY -1
-#define yyclearin (yychar=(YYEMPTY))
-#define yyerrok (yyerrflag=0)
-#ifndef YYINITDEPTH
-#define YYINITDEPTH 200
-#endif
-#ifdef YYSTACKSIZE
-#undef YYMAXDEPTH
-#define YYMAXDEPTH YYSTACKSIZE
-#else
-#ifdef YYMAXDEPTH
-#define YYSTACKSIZE YYMAXDEPTH
-#else
-#define YYSTACKSIZE 10000
-#define YYMAXDEPTH 10000
-#endif
-#endif
-int yydebug;
-int yynerrs;
-int yyerrflag;
-int yychar;
-YYSTYPE yyval;
-YYSTYPE yylval;
-static short *yyss;
-static YYSTYPE *yyvs;
-static int yystacksize;
-static int yygrow ();
-static YYPTR yymalloc YYPARAMS((unsigned));
-static YYPTR yyrealloc YYPARAMS((YYPTR, unsigned));
-#define yyfree(x) free(x)
-#define YYABORT goto yyabort
-#define YYACCEPT goto yyaccept
-#define YYERROR goto yyerrlab
-
-#if YYDEBUG
-#ifdef __cplusplus
-extern "C" char *getenv();
-#else
-extern char *getenv();
-#endif
-#endif
-
-int
-yyparse()
-{
- register int yym, yyn, yystate;
- register YYSTYPE *yyvsp;
- register short *yyssp;
- short *yysse;
-#if YYDEBUG
- register YYCONST char *yys;
-
- if (yys = getenv("YYDEBUG"))
- {
- yyn = *yys;
- if (yyn >= '0' && yyn <= '9')
- yydebug = yyn - '0';
- }
-#endif
-
- yynerrs = 0;
- yyerrflag = 0;
- yychar = (-1);
-
- if (yyss == 0)
- {
- yyss = (short *) yymalloc (YYINITDEPTH * sizeof (short));
- if (yyss == 0)
- goto yyabort;
- yyvs = (YYSTYPE *) yymalloc (YYINITDEPTH * sizeof (YYSTYPE));
- if (yyvs == 0)
- {
- yyfree (yyss);
- goto yyabort;
- }
- yystacksize = YYINITDEPTH;
- }
- yysse = yyss + yystacksize - 1;
- yyssp = yyss;
- yyvsp = yyvs;
- *yyssp = yystate = 0;
-
-yyloop:
- if (yyn = yydefred[yystate]) goto yyreduce;
- if (yychar < 0)
- {
- if ((yychar = yylex()) < 0) yychar = 0;
-#if YYDEBUG
- if (yydebug)
- {
- yys = 0;
- if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
- if (!yys) yys = "illegal-symbol";
- printf("yydebug: state %d, reading %d (%s)\n", yystate,
- yychar, yys);
- }
-#endif
- }
- if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
- yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
- {
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: state %d, shifting to state %d\n",
- yystate, yytable[yyn]);
-#endif
- if (yyssp >= yysse)
- {
- /* FIXME: Rework so there's only one of these. */
- int depth = yyssp - yyss;
- if (yygrow () != 0)
- goto yyoverflow;
- yysse = yyss + yystacksize - 1;
- yyssp = yyss + depth;
- yyvsp = yyvs + depth;
- }
- *++yyssp = yystate = yytable[yyn];
- *++yyvsp = yylval;
- yychar = (-1);
- if (yyerrflag > 0) --yyerrflag;
- goto yyloop;
- }
- if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
- yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
- {
- yyn = yytable[yyn];
- goto yyreduce;
- }
- if (yyerrflag) goto yyinrecovery;
-#ifdef lint
- goto yynewerror;
-#endif
-yynewerror:
- yyerror("syntax error");
-#ifdef lint
- goto yyerrlab;
-#endif
-yyerrlab:
- ++yynerrs;
-yyinrecovery:
- if (yyerrflag < 3)
- {
- yyerrflag = 3;
- for (;;)
- {
- if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
- yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
- {
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: state %d, error recovery shifting\
- to state %d\n", *yyssp, yytable[yyn]);
-#endif
- if (yyssp >= yysse)
- {
- int depth = yyssp - yyss;
- if (yygrow () != 0)
- goto yyoverflow;
- yysse = yyss + yystacksize - 1;
- yyssp = yyss + depth;
- yyvsp = yyvs + depth;
- }
- *++yyssp = yystate = yytable[yyn];
- *++yyvsp = yylval;
- goto yyloop;
- }
- else
- {
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: error recovery discarding state %d\n",
- *yyssp);
-#endif
- if (yyssp <= yyss) goto yyabort;
- --yyssp;
- --yyvsp;
- }
- }
- }
- else
- {
- if (yychar == 0) goto yyabort;
-#if YYDEBUG
- if (yydebug)
- {
- yys = 0;
- if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
- if (!yys) yys = "illegal-symbol";
- printf("yydebug: state %d, error recovery discards token %d (%s)\n",
- yystate, yychar, yys);
- }
-#endif
- yychar = (-1);
- goto yyloop;
- }
-yyreduce:
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: state %d, reducing by rule %d (%s)\n",
- yystate, yyn, yyrule[yyn]);
-#endif
- yym = yylen[yyn];
- yyval = yyvsp[1-yym];
- switch (yyn)
- {
-case 2:
-#line 126 "eqn.y"
-{ yyvsp[0].b->top_level(); non_empty_flag = 1; }
-break;
-case 3:
-#line 131 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 4:
-#line 133 "eqn.y"
-{
- list_box *lb = yyvsp[-1].b->to_list_box();
- if (!lb)
- lb = new list_box(yyvsp[-1].b);
- lb->append(yyvsp[0].b);
- yyval.b = lb;
- }
-break;
-case 5:
-#line 144 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 6:
-#line 146 "eqn.y"
-{ yyval.b = make_mark_box(yyvsp[0].b); }
-break;
-case 7:
-#line 148 "eqn.y"
-{ yyval.b = make_lineup_box(yyvsp[0].b); }
-break;
-case 8:
-#line 153 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 9:
-#line 155 "eqn.y"
-{ yyval.b = make_limit_box(yyvsp[-2].b, 0, yyvsp[0].b); }
-break;
-case 10:
-#line 157 "eqn.y"
-{ yyval.b = make_limit_box(yyvsp[-2].b, yyvsp[0].b, 0); }
-break;
-case 11:
-#line 159 "eqn.y"
-{ yyval.b = make_limit_box(yyvsp[-4].b, yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 12:
-#line 161 "eqn.y"
-{ yyval.b = make_limit_box(yyvsp[-4].b, make_limit_box(yyvsp[-2].b, yyvsp[0].b, 0), 0); }
-break;
-case 13:
-#line 166 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 14:
-#line 168 "eqn.y"
-{ yyval.b = make_sqrt_box(yyvsp[0].b); }
-break;
-case 15:
-#line 170 "eqn.y"
-{ yyval.b = make_over_box(yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 16:
-#line 172 "eqn.y"
-{ yyval.b = make_small_over_box(yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 17:
-#line 177 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 18:
-#line 179 "eqn.y"
-{ yyval.b = make_script_box(yyvsp[-2].b, 0, yyvsp[0].b); }
-break;
-case 19:
-#line 184 "eqn.y"
-{ yyval.b = yyvsp[0].b; }
-break;
-case 20:
-#line 186 "eqn.y"
-{ yyval.b = make_script_box(yyvsp[-2].b, yyvsp[0].b, 0); }
-break;
-case 21:
-#line 188 "eqn.y"
-{ yyval.b = make_script_box(yyvsp[-4].b, yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 22:
-#line 193 "eqn.y"
-{ yyval.b = split_text(yyvsp[0].str); }
-break;
-case 23:
-#line 195 "eqn.y"
-{ yyval.b = new quoted_text_box(yyvsp[0].str); }
-break;
-case 24:
-#line 197 "eqn.y"
-{ yyval.b = split_text(yyvsp[0].str); }
-break;
-case 25:
-#line 199 "eqn.y"
-{ yyval.b = new quoted_text_box(yyvsp[0].str); }
-break;
-case 26:
-#line 201 "eqn.y"
-{ yyval.b = new half_space_box; }
-break;
-case 27:
-#line 203 "eqn.y"
-{ yyval.b = new space_box; }
-break;
-case 28:
-#line 205 "eqn.y"
-{ yyval.b = new tab_box; }
-break;
-case 29:
-#line 207 "eqn.y"
-{ yyval.b = yyvsp[-1].b; }
-break;
-case 30:
-#line 209 "eqn.y"
-{ yyvsp[0].pb->set_alignment(CENTER_ALIGN); yyval.b = yyvsp[0].pb; }
-break;
-case 31:
-#line 211 "eqn.y"
-{ yyvsp[0].pb->set_alignment(LEFT_ALIGN); yyval.b = yyvsp[0].pb; }
-break;
-case 32:
-#line 213 "eqn.y"
-{ yyvsp[0].pb->set_alignment(RIGHT_ALIGN); yyval.b = yyvsp[0].pb; }
-break;
-case 33:
-#line 215 "eqn.y"
-{ yyvsp[0].pb->set_alignment(CENTER_ALIGN); yyval.b = yyvsp[0].pb; }
-break;
-case 34:
-#line 217 "eqn.y"
-{ yyval.b = yyvsp[-1].mb; }
-break;
-case 35:
-#line 219 "eqn.y"
-{ yyval.b = make_delim_box(yyvsp[-3].str, yyvsp[-2].b, yyvsp[0].str); }
-break;
-case 36:
-#line 221 "eqn.y"
-{ yyval.b = make_delim_box(yyvsp[-1].str, yyvsp[0].b, 0); }
-break;
-case 37:
-#line 223 "eqn.y"
-{ yyval.b = make_overline_box(yyvsp[-1].b); }
-break;
-case 38:
-#line 225 "eqn.y"
-{ yyval.b = make_underline_box(yyvsp[-1].b); }
-break;
-case 39:
-#line 227 "eqn.y"
-{ yyval.b = make_prime_box(yyvsp[-1].b); }
-break;
-case 40:
-#line 229 "eqn.y"
-{ yyval.b = make_accent_box(yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 41:
-#line 231 "eqn.y"
-{ yyval.b = make_uaccent_box(yyvsp[-2].b, yyvsp[0].b); }
-break;
-case 42:
-#line 233 "eqn.y"
-{ yyval.b = new font_box(strsave(get_grfont()), yyvsp[0].b); }
-break;
-case 43:
-#line 235 "eqn.y"
-{ yyval.b = new font_box(strsave(get_gbfont()), yyvsp[0].b); }
-break;
-case 44:
-#line 237 "eqn.y"
-{ yyval.b = new font_box(strsave(get_gfont()), yyvsp[0].b); }
-break;
-case 45:
-#line 239 "eqn.y"
-{ yyval.b = new fat_box(yyvsp[0].b); }
-break;
-case 46:
-#line 241 "eqn.y"
-{ yyval.b = new font_box(yyvsp[-1].str, yyvsp[0].b); }
-break;
-case 47:
-#line 243 "eqn.y"
-{ yyval.b = new size_box(yyvsp[-1].str, yyvsp[0].b); }
-break;
-case 48:
-#line 245 "eqn.y"
-{ yyval.b = new hmotion_box(yyvsp[-1].n, yyvsp[0].b); }
-break;
-case 49:
-#line 247 "eqn.y"
-{ yyval.b = new hmotion_box(-yyvsp[-1].n, yyvsp[0].b); }
-break;
-case 50:
-#line 249 "eqn.y"
-{ yyval.b = new vmotion_box(yyvsp[-1].n, yyvsp[0].b); }
-break;
-case 51:
-#line 251 "eqn.y"
-{ yyval.b = new vmotion_box(-yyvsp[-1].n, yyvsp[0].b); }
-break;
-case 52:
-#line 253 "eqn.y"
-{ yyvsp[0].b->set_spacing_type(yyvsp[-1].str); yyval.b = yyvsp[0].b; }
-break;
-case 53:
-#line 255 "eqn.y"
-{ yyval.b = new vcenter_box(yyvsp[0].b); }
-break;
-case 54:
-#line 257 "eqn.y"
-{ yyval.b = make_special_box(yyvsp[-1].str, yyvsp[0].b); }
-break;
-case 55:
-#line 262 "eqn.y"
-{
- int n;
- if (sscanf(yyvsp[0].str, "%d", &n) == 1)
- yyval.n = n;
- a_delete yyvsp[0].str;
- }
-break;
-case 56:
-#line 272 "eqn.y"
-{ yyval.pb = new pile_box(yyvsp[0].b); }
-break;
-case 57:
-#line 274 "eqn.y"
-{ yyvsp[-2].pb->append(yyvsp[0].b); yyval.pb = yyvsp[-2].pb; }
-break;
-case 58:
-#line 279 "eqn.y"
-{ yyval.pb = yyvsp[-1].pb; }
-break;
-case 59:
-#line 281 "eqn.y"
-{ yyvsp[-1].pb->set_space(yyvsp[-3].n); yyval.pb = yyvsp[-1].pb; }
-break;
-case 60:
-#line 286 "eqn.y"
-{ yyval.mb = new matrix_box(yyvsp[0].col); }
-break;
-case 61:
-#line 288 "eqn.y"
-{ yyvsp[-1].mb->append(yyvsp[0].col); yyval.mb = yyvsp[-1].mb; }
-break;
-case 62:
-#line 293 "eqn.y"
-{ yyval.col = new column(yyvsp[0].b); }
-break;
-case 63:
-#line 295 "eqn.y"
-{ yyvsp[-2].col->append(yyvsp[0].b); yyval.col = yyvsp[-2].col; }
-break;
-case 64:
-#line 300 "eqn.y"
-{ yyval.col = yyvsp[-1].col; }
-break;
-case 65:
-#line 302 "eqn.y"
-{ yyvsp[-1].col->set_space(yyvsp[-3].n); yyval.col = yyvsp[-1].col; }
-break;
-case 66:
-#line 307 "eqn.y"
-{ yyvsp[0].col->set_alignment(CENTER_ALIGN); yyval.col = yyvsp[0].col; }
-break;
-case 67:
-#line 309 "eqn.y"
-{ yyvsp[0].col->set_alignment(LEFT_ALIGN); yyval.col = yyvsp[0].col; }
-break;
-case 68:
-#line 311 "eqn.y"
-{ yyvsp[0].col->set_alignment(RIGHT_ALIGN); yyval.col = yyvsp[0].col; }
-break;
-case 69:
-#line 313 "eqn.y"
-{ yyvsp[0].col->set_alignment(CENTER_ALIGN); yyval.col = yyvsp[0].col; }
-break;
-case 70:
-#line 317 "eqn.y"
-{ yyval.str = yyvsp[0].str; }
-break;
-case 71:
-#line 319 "eqn.y"
-{ yyval.str = yyvsp[0].str; }
-break;
-case 72:
-#line 324 "eqn.y"
-{ yyval.str = yyvsp[0].str; }
-break;
-case 73:
-#line 326 "eqn.y"
-{ yyval.str = strsave("{"); }
-break;
-case 74:
-#line 328 "eqn.y"
-{ yyval.str = strsave("}"); }
-break;
-#line 1168 "y.tab.c"
- }
- yyssp -= yym;
- yystate = *yyssp;
- yyvsp -= yym;
- yym = yylhs[yyn];
- if (yystate == 0 && yym == 0)
- {
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: after reduction, shifting from state 0 to\
- state %d\n", YYFINAL);
-#endif
- yystate = YYFINAL;
- *++yyssp = YYFINAL;
- *++yyvsp = yyval;
- if (yychar < 0)
- {
- if ((yychar = yylex()) < 0) yychar = 0;
-#if YYDEBUG
- if (yydebug)
- {
- yys = 0;
- if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
- if (!yys) yys = "illegal-symbol";
- printf("yydebug: state %d, reading %d (%s)\n",
- YYFINAL, yychar, yys);
- }
-#endif
- }
- if (yychar == 0) goto yyaccept;
- goto yyloop;
- }
- if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
- yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
- yystate = yytable[yyn];
- else
- yystate = yydgoto[yym];
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: after reduction, shifting from state %d \
-to state %d\n", *yyssp, yystate);
-#endif
- if (yyssp >= yysse)
- {
- int depth = yyssp - yyss;
- if (yygrow () != 0)
- goto yyoverflow;
- yysse = yyss + yystacksize - 1;
- yyssp = yyss + depth;
- yyvsp = yyvs + depth;
- }
- *++yyssp = yystate;
- *++yyvsp = yyval;
- goto yyloop;
-yyoverflow:
- yyerror("yacc stack overflow");
-yyabort:
- return (1);
-yyaccept:
- return (0);
-}
-
-static int
-yygrow ()
-{
- int old_stacksize = yystacksize;
- short *new_yyss;
- YYSTYPE *new_yyvs;
-
- if (yystacksize >= YYMAXDEPTH)
- return (1);
- yystacksize *= 2;
- if (yystacksize > YYMAXDEPTH)
- yystacksize = YYMAXDEPTH;
-#if YYDEBUG
- if (yydebug)
- printf("yydebug: growing stack size from %d to %d\n",
- old_stacksize, yystacksize);
-#endif
- new_yyss = (short *) yyrealloc (yyss, yystacksize * sizeof (short));
- if (new_yyss == 0)
- return (1);
- new_yyvs = (YYSTYPE *) yyrealloc (yyvs, yystacksize * sizeof (YYSTYPE));
- if (new_yyvs == 0)
- {
- yyfree (new_yyss);
- return (1);
- }
- yyss = new_yyss;
- yyvs = new_yyvs;
- return (0);
-}
-
-static YYPTR
-YYDEFUN (yymalloc, (bytes), unsigned bytes)
-{
- YYPTR ptr = (YYPTR) malloc (bytes);
- if (ptr != 0) return (ptr);
- yyerror ("yyparse: memory exhausted");
- return (0);
-}
-
-static YYPTR
-YYDEFUN (yyrealloc, (old, bytes), YYPTR old YYAND unsigned bytes)
-{
- YYPTR ptr = (YYPTR) realloc (old, bytes);
- if (ptr != 0) return (ptr);
- yyerror ("yyparse: memory exhausted");
- return (0);
-}
diff --git a/src/preproc/eqn/main.cc b/src/preproc/eqn/main.cc
index 5c26ab3b..4f893fe6 100644
--- a/src/preproc/eqn/main.cc
+++ b/src/preproc/eqn/main.cc
@@ -54,10 +54,10 @@ int read_line(FILE *fp, string *p)
p->clear();
int c = -1;
while ((c = getc(fp)) != EOF) {
- if (!illegal_input_char(c))
+ if (!invalid_input_char(c))
*p += char(c);
else
- error("illegal input character code `%1'", c);
+ error("invalid input character code `%1'", c);
if (c == '\n')
break;
}
@@ -312,9 +312,9 @@ int main(int argc, char **argv)
case 'd':
if (optarg[0] == '\0' || optarg[1] == '\0')
error("-d requires two character argument");
- else if (illegal_input_char(optarg[0]))
+ else if (invalid_input_char(optarg[0]))
error("bad delimiter `%1'", optarg[0]);
- else if (illegal_input_char(optarg[1]))
+ else if (invalid_input_char(optarg[1]))
error("bad delimiter `%1'", optarg[1]);
else {
start_delim = optarg[0];
diff --git a/src/preproc/grn/grn.man b/src/preproc/grn/grn.man
index 72aab1d3..7c885f1f 100644
--- a/src/preproc/grn/grn.man
+++ b/src/preproc/grn/grn.man
@@ -1,6 +1,6 @@
'\" t
.ig
-Copyright (C) 2000, 2001 Free Software Foundation, Inc.
+Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
Permission is granted to make and distribute verbatim copies of
this manual provided the copyright notice and this permission notice
@@ -217,7 +217,7 @@ confusion with
There is
.I no
default for stipples (unless one is set by the default command), and it is
-illegal to include a
+invalid to include a
.I gremlin
picture with polygons without specifying a
stipple font.
diff --git a/src/preproc/grn/main.cc b/src/preproc/grn/main.cc
index f962894d..9b09ea63 100644
--- a/src/preproc/grn/main.cc
+++ b/src/preproc/grn/main.cc
@@ -848,7 +848,7 @@ interpret(char *line)
if (par > 0.0)
xscale *= par;
else
- error("illegal scale value on line %1", linenum);
+ error("invalid scale value on line %1", linenum);
break;
case 'f': /* file */
diff --git a/src/preproc/pic/main.cc b/src/preproc/pic/main.cc
index b795d481..e0a1d813 100644
--- a/src/preproc/pic/main.cc
+++ b/src/preproc/pic/main.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989-1992, 2000, 2001 Free Software Foundation, Inc.
+/* Copyright (C) 1989-1992, 2000, 2001, 2002 Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
This file is part of groff.
@@ -80,8 +80,8 @@ int top_input::get()
return c;
}
int c = getc(fp);
- while (illegal_input_char(c)) {
- error("illegal input character code %1", int(c));
+ while (invalid_input_char(c)) {
+ error("invalid input character code %1", int(c));
c = getc(fp);
bol = 0;
}
@@ -152,8 +152,8 @@ int top_input::peek()
if (push_back[0] != EOF)
return push_back[0];
int c = getc(fp);
- while (illegal_input_char(c)) {
- error("illegal input character code %1", int(c));
+ while (invalid_input_char(c)) {
+ error("invalid input character code %1", int(c));
c = getc(fp);
bol = 0;
}
diff --git a/src/preproc/pic/pic.man b/src/preproc/pic/pic.man
index 1804e660..fd17cd5f 100644
--- a/src/preproc/pic/pic.man
+++ b/src/preproc/pic/pic.man
@@ -884,7 +884,7 @@ W. Richard Stevens - Examples of picMacros
<http://www.kohala.com/start/troff/pic.examples.ps>
.SH BUGS
.LP
-Input characters that are illegal for
+Input characters that are invalid for
.B groff
(ie those with
.SM ASCII
diff --git a/src/preproc/refer/command.cc b/src/preproc/refer/command.cc
index bf88c89d..a7c6bfb8 100644
--- a/src/preproc/refer/command.cc
+++ b/src/preproc/refer/command.cc
@@ -1,5 +1,6 @@
// -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2001 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2001, 2002
+ Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
This file is part of groff.
@@ -193,9 +194,9 @@ void input_stack::push_file(const char *fn)
}
if (c == EOF)
break;
- if (illegal_input_char(c))
+ if (invalid_input_char(c))
error_with_file_and_line(fn, lineno,
- "illegal input character code %1", int(c));
+ "invalid input character code %1", int(c));
else {
buf += c;
if (c == '\n') {
diff --git a/src/preproc/refer/refer.cc b/src/preproc/refer/refer.cc
index c39def73..33df35ca 100644
--- a/src/preproc/refer/refer.cc
+++ b/src/preproc/refer/refer.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989-1992, 2000, 2001 Free Software Foundation, Inc.
+/* Copyright (C) 1989-1992, 2000, 2001, 2002 Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
This file is part of groff.
@@ -445,8 +445,8 @@ static void do_file(const char *filename)
line += '\n';
break;
}
- if (illegal_input_char(c))
- error("illegal input character code %1", c);
+ if (invalid_input_char(c))
+ error("invalid input character code %1", c);
else {
line += c;
if (c == '\n')
@@ -476,8 +476,8 @@ static void do_file(const char *filename)
int d = getc(fp);
if (d == ']') {
while ((d = getc(fp)) != '\n' && d != EOF) {
- if (illegal_input_char(d))
- error("illegal input character code %1", d);
+ if (invalid_input_char(d))
+ error("invalid input character code %1", d);
else
post += d;
}
@@ -486,8 +486,8 @@ static void do_file(const char *filename)
if (d != EOF)
ungetc(d, fp);
}
- if (illegal_input_char(c))
- error("illegal input character code %1", c);
+ if (invalid_input_char(c))
+ error("invalid input character code %1", c);
else
str += c;
start_of_line = (c == '\n');
@@ -580,8 +580,8 @@ static void do_file(const char *filename)
"missing `.R2' line");
break;
}
- if (illegal_input_char(c))
- error("illegal input character code %1", int(c));
+ if (invalid_input_char(c))
+ error("invalid input character code %1", int(c));
else {
line += c;
start_of_line = c == '\n';
@@ -1113,8 +1113,8 @@ void do_bib(const char *filename)
int c = getc(fp);
if (c == EOF)
break;
- if (illegal_input_char(c)) {
- error("illegal input character code %1", c);
+ if (invalid_input_char(c)) {
+ error("invalid input character code %1", c);
continue;
}
switch (state) {
diff --git a/src/preproc/tbl/main.cc b/src/preproc/tbl/main.cc
index 45e25a03..c28f4edb 100644
--- a/src/preproc/tbl/main.cc
+++ b/src/preproc/tbl/main.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
@@ -110,7 +110,7 @@ int table_input::get()
else {
state = MIDDLE;
if (c == '\0') {
- error("illegal input character code 0");
+ error("invalid input character code 0");
break;
}
}
@@ -139,7 +139,7 @@ int table_input::get()
current_lineno++;
}
else if (c == '\0') {
- error("illegal input character code 0");
+ error("invalid input character code 0");
break;
}
return c;
diff --git a/src/roff/troff/env.cc b/src/roff/troff/env.cc
index 69cfa205..51a9447c 100644
--- a/src/roff/troff/env.cc
+++ b/src/roff/troff/env.cc
@@ -2095,7 +2095,7 @@ void environment::add_html_tag(const char *name)
macro *m = new macro;
m->append_str("html-tag:");
for (const char *p = name; *p; p++)
- if (!illegal_input_char((unsigned char)*p))
+ if (!invalid_input_char((unsigned char)*p))
m->append(*p);
add_node(new special_node(*m));
if (strcmp(name, ".nf") == 0)
@@ -2121,7 +2121,7 @@ void environment::add_html_tag(const char *name, int i)
macro *m = new macro;
m->append_str("html-tag:");
for (const char *p = name; *p; p++)
- if (!illegal_input_char((unsigned char)*p))
+ if (!invalid_input_char((unsigned char)*p))
m->append(*p);
m->append(' ');
m->append_int(i);
diff --git a/src/roff/troff/input.cc b/src/roff/troff/input.cc
index 087c6795..29474e51 100644
--- a/src/roff/troff/input.cc
+++ b/src/roff/troff/input.cc
@@ -330,8 +330,8 @@ int file_iterator::fill(node **)
int c = getc(fp);
if (c == EOF)
break;
- if (illegal_input_char(c))
- warning(WARN_INPUT, "illegal input character code %1", int(c));
+ if (invalid_input_char(c))
+ warning(WARN_INPUT, "invalid input character code %1", int(c));
else {
*p++ = c;
if (c == '\n') {
@@ -357,8 +357,8 @@ int file_iterator::fill(node **)
int file_iterator::peek()
{
int c = getc(fp);
- while (illegal_input_char(c)) {
- warning(WARN_INPUT, "illegal input character code %1", int(c));
+ while (invalid_input_char(c)) {
+ warning(WARN_INPUT, "invalid input character code %1", int(c));
c = getc(fp);
}
if (c != EOF)
@@ -692,7 +692,7 @@ static int get_char_for_escape_name()
copy_mode_error("end of input in escape name");
return '\0';
default:
- if (!illegal_input_char(c))
+ if (!invalid_input_char(c))
break;
// fall through
case '\n':
@@ -1384,7 +1384,7 @@ static node *do_zero_width()
&& (compatible_flag || input_stack::get_level() == start_level))
break;
if (!tok.add_to_node_list(&rev))
- error("illegal token in argument to \\Z");
+ error("invalid token in argument to \\Z");
}
node *n = 0;
while (rev) {
@@ -2337,7 +2337,7 @@ inline int possibly_handle_first_page_transition()
static int transparent_translate(int cc)
{
- if (!illegal_input_char(cc)) {
+ if (!invalid_input_char(cc)) {
charinfo *ci = charset_table[cc];
switch (ci->get_special_translation(1)) {
case charinfo::TRANSLATE_SPACE:
@@ -3467,7 +3467,7 @@ void read_request()
while (c == ' ')
c = get_copy(0);
while (c != EOF && c != '\n' && c != ' ') {
- if (!illegal_input_char(c)) {
+ if (!invalid_input_char(c)) {
if (reading_from_terminal)
fputc(c, stderr);
had_prompt = 1;
@@ -3488,8 +3488,8 @@ void read_request()
int nl = 0;
int c;
while ((c = getchar()) != EOF) {
- if (illegal_input_char(c))
- warning(WARN_INPUT, "illegal input character code %1", int(c));
+ if (invalid_input_char(c))
+ warning(WARN_INPUT, "invalid input character code %1", int(c));
else {
if (c == '\n') {
if (nl)
@@ -4568,7 +4568,7 @@ static void encode_char(macro *mac, char c)
}
}
else {
- error("%1 is illegal within \\X", tok.description());
+ error("%1 is invalid within \\X", tok.description());
}
}
else {
@@ -5156,7 +5156,7 @@ int ps_get_line(char *buf, FILE *fp, const char* filename)
int err = 0;
while (c != '\r' && c != '\n' && c != EOF) {
if ((c < 0x1b && !white_space(c)) || c == 0x7f)
- error("illegal input character code %1 in `%2'", int(c), filename);
+ error("invalid input character code %1 in `%2'", int(c), filename);
else if (i < PS_LINE_MAX)
buf[i++] = c;
else if (!err) {
@@ -5352,7 +5352,7 @@ const char *asciify(int c)
buf[1] = ':';
break;
default:
- if (illegal_input_char(c))
+ if (invalid_input_char(c))
buf[0] = '\0';
else
buf[0] = c;
@@ -5378,7 +5378,7 @@ const char *input_char_description(int c)
return "a node";
}
static char buf[sizeof("magic character code ") + 1 + INT_DIGITS];
- if (illegal_input_char(c)) {
+ if (invalid_input_char(c)) {
const char *s = asciify(c);
if (*s) {
buf[0] = '`';
@@ -5999,7 +5999,7 @@ char *read_string()
;
int i = 0;
while (c != '\n' && c != EOF) {
- if (!illegal_input_char(c)) {
+ if (!invalid_input_char(c)) {
if (i + 2 > len) {
char *tem = s;
s = new char[len*2];
@@ -6116,8 +6116,8 @@ void transparent_file()
int c = getc(fp);
if (c == EOF)
break;
- if (illegal_input_char(c))
- warning(WARN_INPUT, "illegal input character code %1", int(c));
+ if (invalid_input_char(c))
+ warning(WARN_INPUT, "invalid input character code %1", int(c));
else {
curdiv->transparent_output(c);
bol = c == '\n';
@@ -6348,7 +6348,7 @@ static void set_string(const char *name, const char *value)
{
macro *m = new macro;
for (const char *p = value; *p; p++)
- if (!illegal_input_char((unsigned char)*p))
+ if (!invalid_input_char((unsigned char)*p))
m->append(*p);
request_dictionary.define(name, m);
}
diff --git a/src/roff/troff/troff.man b/src/roff/troff/troff.man
index 0cda2893..a78cd75c 100644
--- a/src/roff/troff/troff.man
+++ b/src/roff/troff/troff.man
@@ -415,7 +415,7 @@ This is enabled by default.
.
.TP
.BR ig "\t262144"
-Illegal escapes in text ignored with the
+Invalid escapes in text ignored with the
.B ig
request.
.
@@ -424,7 +424,7 @@ text.
.
.TP
.BR input "\t16384"
-Illegal input characters.
+Invalid input characters.
.
.TP
.BR mac "\t512"
diff --git a/tmac/e.tmac b/tmac/e.tmac
index 8ea4074c..28349ef5 100644
--- a/tmac/e.tmac
+++ b/tmac/e.tmac
@@ -795,7 +795,7 @@
.sp \\n(bsu+\\n(.Lv-1v
..
.de @( \" --- begin keep
-.if !"\\n(.z"" .tm Line \\n(c. -- Illegal nested keep \\n(.z
+.if !"\\n(.z"" .tm Line \\n(c. -- Invalid nested keep \\n(.z
.@M
.di |k
\!'rs
@@ -1215,7 +1215,7 @@ in \\f2\\*([B\\f1, \c
.\" *** FOOTNOTING ***
.de (f \" *** begin footnote
.ec
-.if "\\n(.z"|f" .tm Line \\n(c. -- Illegal footnote nesting
+.if "\\n(.z"|f" .tm Line \\n(c. -- Invalid footnote nesting
.ie "\\n(.z"" \
\{\
. nr _D \\n(dn
diff --git a/win32-diffs b/win32-diffs
index ec910dd9..cc177ab3 100644
--- a/win32-diffs
+++ b/win32-diffs
@@ -2867,7 +2867,7 @@ diff -aruN groff/src/libs/libgroff/Makefile.msc groff.win32/src/libs/libgroff/Ma
+ getopt.obj \
+ htmlindicate.obj \
+ iftoa.obj \
-+ illegal.obj \
++ invalid.obj \
+ itoa.obj \
+ lf.obj \
+ lineno.obj \
diff --git a/src/libs/libdriver/input.cc b/src/libs/libdriver/input.cc
index 97ab466b..4fcfb700 100644
--- a/src/libs/libdriver/input.cc
+++ b/src/libs/libdriver/input.cc
@@ -381,7 +381,7 @@ envp_size = sizeof(environment *);
ColorArg color_from_Df_command(IntArg);
// transform old color into new
void delete_current_env(void); // delete global var current_env
-void fatal_command(char); // abort for illegal command
+void fatal_command(char); // abort for invalid command
inline Char get_char(void); // read next character from input stream
ColorArg get_color_arg(void); // read in argument for new color cmds
IntArray *get_D_fixed_args(const size_t);
@@ -611,12 +611,12 @@ void delete_current_env(void)
//////////////////////////////////////////////////////////////////////
/* fatal_command():
- Emit error message about illegal command and abort.
+ Emit error message about invalid command and abort.
*/
void
fatal_command(char command)
{
- fatal("`%1' command illegal before first `p' command", command);
+ fatal("`%1' command invalid before first `p' command", command);
}
//////////////////////////////////////////////////////////////////////
@@ -1273,7 +1273,7 @@ parse_color_command(color *col)
col->set_rgb(red, green, blue);
break;
default:
- error("illegal color scheme `%1'", (int) subcmd);
+ error("invalid color scheme `%1'", (int) subcmd);
break;
} // end of color subcommands
}
@@ -1482,7 +1482,7 @@ parse_x_command(void)
{
char *str_arg = get_extended_arg(); // includes line skip
if (npages <= 0)
- error("`x X' command illegal before first `p' command");
+ error("`x X' command invalid before first `p' command");
else
pr->special(str_arg, current_env);
delete str_arg;
diff --git a/src/preproc/eqn/lex.cc b/src/preproc/eqn/lex.cc
index e14053d1..4e62f86c 100644
--- a/src/preproc/eqn/lex.cc
+++ b/src/preproc/eqn/lex.cc
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
@@ -371,8 +371,8 @@ int file_input::read_line()
int c = getc(fp);
if (c == EOF)
break;
- else if (illegal_input_char(c))
- lex_error("illegal input character code %1", c);
+ else if (invalid_input_char(c))
+ lex_error("invalid input character code %1", c);
else {
line += char(c);
if (c == '\n')
@@ -467,7 +467,7 @@ int top_input::get_location(char **fnp, int *lnp)
return 1;
}
// Character representing $1. Must be illegal input character.
#define ARG1 14
argument_macro_input::argument_macro_input(const char *body, int ac,
@@ -467,7 +467,7 @@ int top_input::get_location(char **fnp, int *lnp)
return 1;
}
-// Character representing $1. Must be illegal input character.
+// Character representing $1. Must be invalid input character.
#define ARG1 14
argument_macro_input::argument_macro_input(const char *body, int ac,
diff --git a/src/preproc/pic/lex.cc b/src/preproc/pic/lex.cc
index 3aeb30c0..f25d0ff9 100644
--- a/src/preproc/pic/lex.cc
+++ b/src/preproc/pic/lex.cc
@@ -84,8 +84,8 @@ int file_input::read_line()
int c = getc(fp);
if (c == EOF)
break;
- else if (illegal_input_char(c))
- lex_error("illegal input character code %1", c);
+ else if (invalid_input_char(c))
+ lex_error("invalid input character code %1", c);
else {
line += char(c);
if (c == '\n')
@@ -154,7 +154,7 @@ int macro_input::peek()
return (unsigned char)*p;
}
// Character representing $1. Must be illegal input character.
#define ARG1 14
char *process_body(const char *body)
@@ -1626,8 +1626,8 @@ simple_file_input::~simple_file_input()
int simple_file_input::get()
{
int c = getc(fp);
- while (illegal_input_char(c)) {
- error("illegal input character code %1", c);
+ while (invalid_input_char(c)) {
+ error("invalid input character code %1", c);
c = getc(fp);
}
if (c == '\n')
@@ -1638,8 +1638,8 @@ int simple_file_input::get()
int simple_file_input::peek()
{
int c = getc(fp);
- while (illegal_input_char(c)) {
- error("illegal input character code %1", c);
+ while (invalid_input_char(c)) {
+ error("invalid input character code %1", c);
c = getc(fp);
}
if (c != EOF)
@@ -154,7 +154,7 @@ int macro_input::peek()
return (unsigned char)*p;
}
-// Character representing $1. Must be illegal input character.
+// Character representing $1. Must be invalid input character.
#define ARG1 14
char *process_body(const char *body)